@@ -149,6 +149,14 @@ class Document(ElementProxy):
         """
         return Sections(self._element)
 
+    @property
+    def settings(self):
+        """
+        A |Settings| object providing access to the document-level settings
+        for this document.
+        """
+        return self._part.settings
+
     @property
     def styles(self):
         """
