@@ -9,7 +9,7 @@ from __future__ import absolute_import, print_function, unicode_literals
 import pytest
 
 from docx.enum.style import WD_STYLE_TYPE
-from docx.enum.table import WD_TABLE_ALIGNMENT
+from docx.enum.table import WD_TABLE_ALIGNMENT, WD_TABLE_DIRECTION
 from docx.oxml import parse_xml
 from docx.oxml.table import CT_Tc
 from docx.parts.document import DocumentPart
@@ -26,6 +26,49 @@ from .unitutil.mock import instance_mock, property_mock
 
 class DescribeTable(object):
 
+    def it_can_add_a_row(self, add_row_fixture):
+        table, expected_xml = add_row_fixture
+        row = table.add_row()
+        assert table._tbl.xml == expected_xml
+        assert isinstance(row, _Row)
+        assert row._tr is table._tbl.tr_lst[-1]
+        assert row._parent is table
+
+    def it_can_add_a_column(self, add_column_fixture):
+        table, width, expected_xml = add_column_fixture
+        column = table.add_column(width)
+        assert table._tbl.xml == expected_xml
+        assert isinstance(column, _Column)
+        assert column._gridCol is table._tbl.tblGrid.gridCol_lst[-1]
+        assert column._parent is table
+
+    def it_provides_access_to_a_cell_by_row_and_col_indices(self, table):
+        for row_idx in range(2):
+            for col_idx in range(2):
+                cell = table.cell(row_idx, col_idx)
+                assert isinstance(cell, _Cell)
+                tr = table._tbl.tr_lst[row_idx]
+                tc = tr.tc_lst[col_idx]
+                assert tc is cell._tc
+
+    def it_provides_access_to_the_table_rows(self, table):
+        rows = table.rows
+        assert isinstance(rows, _Rows)
+
+    def it_provides_access_to_the_table_columns(self, table):
+        columns = table.columns
+        assert isinstance(columns, _Columns)
+
+    def it_provides_access_to_the_cells_in_a_column(self, col_cells_fixture):
+        table, column_idx, expected_cells = col_cells_fixture
+        column_cells = table.column_cells(column_idx)
+        assert column_cells == expected_cells
+
+    def it_provides_access_to_the_cells_in_a_row(self, row_cells_fixture):
+        table, row_idx, expected_cells = row_cells_fixture
+        row_cells = table.row_cells(row_idx)
+        assert row_cells == expected_cells
+
     def it_knows_its_alignment_setting(self, alignment_get_fixture):
         table, expected_value = alignment_get_fixture
         assert table.alignment == expected_value
@@ -44,6 +87,19 @@ class DescribeTable(object):
         table.autofit = new_value
         assert table._tbl.xml == expected_xml
 
+    def it_knows_it_is_the_table_its_children_belong_to(self, table_fixture):
+        table = table_fixture
+        assert table.table is table
+
+    def it_knows_its_direction(self, direction_get_fixture):
+        table, expected_value = direction_get_fixture
+        assert table.table_direction == expected_value
+
+    def it_can_change_its_direction(self, direction_set_fixture):
+        table, new_value, expected_xml = direction_set_fixture
+        table.table_direction = new_value
+        assert table._element.xml == expected_xml
+
     def it_knows_its_table_style(self, style_get_fixture):
         table, style_id_, style_ = style_get_fixture
         style = table.style
@@ -60,56 +116,6 @@ class DescribeTable(object):
         )
         assert table._tbl.xml == expected_xml
 
-    def it_knows_it_is_the_table_its_children_belong_to(self, table_fixture):
-        table = table_fixture
-        assert table.table is table
-
-    def it_knows_its_column_count_to_help(self, column_count_fixture):
-        table, expected_value = column_count_fixture
-        column_count = table._column_count
-        assert column_count == expected_value
-
-    def it_provides_access_to_the_table_rows(self, table):
-        rows = table.rows
-        assert isinstance(rows, _Rows)
-
-    def it_provides_access_to_the_table_columns(self, table):
-        columns = table.columns
-        assert isinstance(columns, _Columns)
-
-    def it_provides_access_to_a_cell_by_row_and_col_indices(self, table):
-        for row_idx in range(2):
-            for col_idx in range(2):
-                cell = table.cell(row_idx, col_idx)
-                assert isinstance(cell, _Cell)
-                tr = table._tbl.tr_lst[row_idx]
-                tc = tr.tc_lst[col_idx]
-                assert tc is cell._tc
-
-    def it_provides_access_to_the_cells_in_a_column(self, col_cells_fixture):
-        table, column_idx, expected_cells = col_cells_fixture
-        column_cells = table.column_cells(column_idx)
-        assert column_cells == expected_cells
-
-    def it_provides_access_to_the_cells_in_a_row(self, row_cells_fixture):
-        table, row_idx, expected_cells = row_cells_fixture
-        row_cells = table.row_cells(row_idx)
-        assert row_cells == expected_cells
-
-    def it_can_add_a_row(self, add_row_fixture):
-        table, expected_xml = add_row_fixture
-        row = table.add_row()
-        assert table._tbl.xml == expected_xml
-        assert isinstance(row, _Row)
-        assert row._tr is table._tbl.tr_lst[1]
-
-    def it_can_add_a_column(self, add_column_fixture):
-        table, expected_xml = add_column_fixture
-        column = table.add_column()
-        assert table._tbl.xml == expected_xml
-        assert isinstance(column, _Column)
-        assert column._gridCol is table._tbl.tblGrid.gridCol_lst[1]
-
     def it_provides_access_to_its_cells_to_help(self, cells_fixture):
         table, cell_count, unique_count, matches = cells_fixture
         cells = table._cells
@@ -120,20 +126,28 @@ class DescribeTable(object):
             for idx in matching_idxs[1:]:
                 assert cells[idx] is cells[comparator_idx]
 
+    def it_knows_its_column_count_to_help(self, column_count_fixture):
+        table, expected_value = column_count_fixture
+        column_count = table._column_count
+        assert column_count == expected_value
+
     # fixtures -------------------------------------------------------
 
     @pytest.fixture
     def add_column_fixture(self):
-        tbl = _tbl_bldr(2, 1).element
+        snippets = snippet_seq('add-row-col')
+        tbl = parse_xml(snippets[0])
         table = Table(tbl, None)
-        expected_xml = _tbl_bldr(2, 2).xml()
-        return table, expected_xml
+        width = Inches(1.5)
+        expected_xml = snippets[2]
+        return table, width, expected_xml
 
     @pytest.fixture
     def add_row_fixture(self):
-        tbl = _tbl_bldr(rows=1, cols=2).element
+        snippets = snippet_seq('add-row-col')
+        tbl = parse_xml(snippets[0])
         table = Table(tbl, None)
-        expected_xml = _tbl_bldr(rows=2, cols=2).xml()
+        expected_xml = snippets[1]
         return table, expected_xml
 
     @pytest.fixture(params=[
@@ -219,6 +233,33 @@ class DescribeTable(object):
         table = Table(element(tbl_cxml), None)
         return table, expected_value
 
+    @pytest.fixture(params=[
+        ('w:tbl/w:tblPr',                        None),
+        ('w:tbl/w:tblPr/w:bidiVisual',           WD_TABLE_DIRECTION.RTL),
+        ('w:tbl/w:tblPr/w:bidiVisual{w:val=0}',  WD_TABLE_DIRECTION.LTR),
+        ('w:tbl/w:tblPr/w:bidiVisual{w:val=on}', WD_TABLE_DIRECTION.RTL),
+    ])
+    def direction_get_fixture(self, request):
+        tbl_cxml, expected_value = request.param
+        table = Table(element(tbl_cxml), None)
+        return table, expected_value
+
+    @pytest.fixture(params=[
+        ('w:tbl/w:tblPr',                       WD_TABLE_DIRECTION.RTL,
+         'w:tbl/w:tblPr/w:bidiVisual'),
+        ('w:tbl/w:tblPr/w:bidiVisual',          WD_TABLE_DIRECTION.LTR,
+         'w:tbl/w:tblPr/w:bidiVisual{w:val=0}'),
+        ('w:tbl/w:tblPr/w:bidiVisual{w:val=0}', WD_TABLE_DIRECTION.RTL,
+         'w:tbl/w:tblPr/w:bidiVisual'),
+        ('w:tbl/w:tblPr/w:bidiVisual{w:val=1}', None,
+         'w:tbl/w:tblPr'),
+    ])
+    def direction_set_fixture(self, request):
+        tbl_cxml, new_value, expected_cxml = request.param
+        table = Table(element(tbl_cxml), None)
+        expected_xml = xml(expected_cxml)
+        return table, new_value, expected_xml
+
     @pytest.fixture
     def row_cells_fixture(self, _cells_, _column_count_):
         table = Table(None, None)
@@ -338,8 +379,8 @@ class Describe_Cell(object):
 
     def it_can_add_a_table(self, add_table_fixture):
         cell, expected_xml = add_table_fixture
-        table = cell.add_table(rows=0, cols=0)
-        assert cell._tc.xml == expected_xml
+        table = cell.add_table(rows=2, cols=2)
+        assert cell._element.xml == expected_xml
         assert isinstance(table, Table)
 
     def it_can_merge_itself_with_other_cells(self, merge_fixture):
@@ -363,19 +404,10 @@ class Describe_Cell(object):
         expected_xml = xml(after_tc_cxml)
         return cell, expected_xml
 
-    @pytest.fixture(params=[
-        ('w:tc',     'w:tc/(w:tbl'),
-        ('w:tc/w:p', 'w:tc/(w:p, w:tbl'),
-    ])
+    @pytest.fixture
     def add_table_fixture(self, request):
-        tc_cxml, after_tc_cxml = request.param
-        # the table has some overhead elements, also a blank para after since
-        # it's in a cell.
-        after_tc_cxml += (
-            '/(w:tblPr/w:tblW{w:type=auto,w:w=0},w:tblGrid),w:p)'
-        )
-        cell = _Cell(element(tc_cxml), None)
-        expected_xml = xml(after_tc_cxml)
+        cell = _Cell(element('w:tc/w:p'), None)
+        expected_xml = snippet_seq('new-tbl')[1]
         return cell, expected_xml
 
     @pytest.fixture
